@@ -27,6 +27,7 @@ typedef struct CitusScanState
 
 
 /* custom scan methods for all executors */
+extern CustomScanMethods AdaptiveExecutorCustomScanMethods;
 extern CustomScanMethods RealTimeCustomScanMethods;
 extern CustomScanMethods TaskTrackerCustomScanMethods;
 extern CustomScanMethods RouterCustomScanMethods;
@@ -37,5 +38,7 @@ extern CustomScanMethods DelayedErrorCustomScanMethods;
 extern void RegisterCitusCustomScanMethods(void);
 extern void CitusExplainScan(CustomScanState *node, List *ancestors, struct
 							 ExplainState *es);
+extern TupleDesc ScanStateGetTupleDescriptor(CitusScanState *scanState);
+extern EState * ScanStateGetExecutorState(CitusScanState *scanState);
 
 #endif /* CITUS_CUSTOM_SCAN_H */
