@@ -12,11 +12,8 @@
 #define CITUS_RULEUTILS_H
 
 #include "postgres.h" /* IWYU pragma: keep */
-#include "c.h"
 
-#if (PG_VERSION_NUM >= 100000)
 #include "catalog/pg_sequence.h"
-#endif
 #include "commands/sequence.h"
 #include "lib/stringinfo.h"
 #include "nodes/parsenodes.h"
@@ -38,6 +35,8 @@ extern void EnsureRelationKindSupported(Oid relationId);
 extern char * pg_get_tablecolumnoptionsdef_string(Oid tableRelationId);
 extern void deparse_shard_index_statement(IndexStmt *origStmt, Oid distrelid,
 										  int64 shardid, StringInfo buffer);
+extern void deparse_shard_reindex_statement(ReindexStmt *origStmt, Oid distrelid,
+											int64 shardid, StringInfo buffer);
 extern char * pg_get_indexclusterdef_string(Oid indexRelationId);
 extern List * pg_get_table_grants(Oid relationId);
 extern bool contain_nextval_expression_walker(Node *node, void *context);
@@ -46,6 +45,7 @@ extern const char * RoleSpecString(RoleSpec *spec);
 
 /* Function declarations for version dependent PostgreSQL ruleutils functions */
 extern void pg_get_query_def(Query *query, StringInfo buffer);
+char * pg_get_rule_expr(Node *expression);
 extern void deparse_shard_query(Query *query, Oid distrelid, int64 shardid,
 								StringInfo buffer);
 extern char * generate_relation_name(Oid relid, List *namespaces);
