@@ -29,14 +29,28 @@ extern int MultiShardConnectionType;
 
 
 extern bool WritableStandbyCoordinator;
+extern bool ForceMaxQueryParallelization;
+extern int MaxAdaptiveExecutorPoolSize;
+extern int ExecutorSlowStartInterval;
 
 
 extern void CitusExecutorStart(QueryDesc *queryDesc, int eflags);
+extern void CitusExecutorRun(QueryDesc *queryDesc, ScanDirection direction, uint64 count,
+							 bool execute_once);
+extern TupleTableSlot * AdaptiveExecutor(CustomScanState *node);
+extern uint64 ExecuteTaskListExtended(RowModifyLevel modLevel, List *taskList,
+									  TupleDesc tupleDescriptor,
+									  Tuplestorestate *tupleStore,
+									  bool hasReturning, int targetPoolSize);
+extern void ExecuteUtilityTaskListWithoutResults(List *taskList);
+extern uint64 ExecuteTaskList(RowModifyLevel modLevel, List *taskList, int
+							  targetPoolSize);
+extern TupleTableSlot * CitusExecScan(CustomScanState *node);
 extern TupleTableSlot * ReturnTupleFromTuplestore(CitusScanState *scanState);
 extern void LoadTuplesIntoTupleStore(CitusScanState *citusScanState, Job *workerJob);
 extern void ReadFileIntoTupleStore(char *fileName, char *copyFormat, TupleDesc
 								   tupleDescriptor, Tuplestorestate *tupstore);
-extern Query * ParseQueryString(const char *queryString);
+extern Query * ParseQueryString(const char *queryString, Oid *paramOids, int numParams);
 extern void ExecuteQueryStringIntoDestReceiver(const char *queryString, ParamListInfo
 											   params,
 											   DestReceiver *dest);
@@ -45,6 +59,9 @@ extern void ExecuteQueryIntoDestReceiver(Query *query, ParamListInfo params,
 extern void ExecutePlanIntoDestReceiver(PlannedStmt *queryPlan, ParamListInfo params,
 										DestReceiver *dest);
 extern void SetLocalMultiShardModifyModeToSequential(void);
+extern void SetLocalForceMaxQueryParallelization(void);
+extern void SortTupleStore(CitusScanState *scanState);
+extern bool DistributedPlanModifiesDatabase(DistributedPlan *plan);
 
 
 #endif /* MULTI_EXECUTOR_H */
