@@ -146,6 +146,6 @@ extern bool IsPartitionColumn(Expr *columnExpression, Query *query);
 extern void FindReferencedTableColumn(Expr *columnExpression, List *parentQueryList,
 									  Query *query, Oid *relationId, Var **column);
 
-extern bool IsGroupBySubsetOfDistinct(List *groupClause, List *distinctClause);
+extern bool IsGroupBySubsetOfDistinct(List *groupClauses, List *distinctClauses);
 
 #endif   /* MULTI_LOGICAL_OPTIMIZER_H */
