@@ -51,13 +51,12 @@ typedef enum CitusRTEKind
 	CITUS_RTE_SUBQUERY = RTE_SUBQUERY,  /* subquery in FROM */
 	CITUS_RTE_JOIN = RTE_JOIN,          /* join */
 	CITUS_RTE_FUNCTION = RTE_FUNCTION,  /* function in FROM */
-#if (PG_VERSION_NUM >= 100000)
 	CITUS_RTE_TABLEFUNC = RTE_TABLEFUNC, /* TableFunc(.., column list) */
-#endif
 	CITUS_RTE_VALUES = RTE_VALUES,      /* VALUES (<exprlist>), (<exprlist>), ... */
 	CITUS_RTE_CTE = RTE_CTE,            /* common table expr (WITH list element) */
-#if (PG_VERSION_NUM >= 100000)
 	CITUS_RTE_NAMEDTUPLESTORE = RTE_NAMEDTUPLESTORE, /* tuplestore, e.g. for triggers */
+#if (PG_VERSION_NUM >= 120000)
+	CITUS_RTE_RESULT = RTE_RESULT,      /* RTE represents an empty FROM clause */
 #endif
 	CITUS_RTE_SHARD,
 	CITUS_RTE_REMOTE_QUERY
@@ -110,6 +109,15 @@ typedef enum
 } BoundaryNodeJobType;
 
 
+/* Enumeration that specifies extent of DML modifications */
+typedef enum RowModifyLevel
+{
+	ROW_MODIFY_NONE = 0,
+	ROW_MODIFY_READONLY = 1,
+	ROW_MODIFY_COMMUTATIVE = 2,
+	ROW_MODIFY_NONCOMMUTATIVE = 3
+} RowModifyLevel;
+
 /*
  * Job represents a logical unit of work that contains one set of data transfers
  * in our physical plan. The physical planner maps each SQL query into one or
@@ -183,11 +191,25 @@ typedef struct Task
 	ShardInterval *shardInterval;  /* only applies to merge tasks */
 	bool assignmentConstrained;    /* only applies to merge tasks */
 	TaskExecution *taskExecution;  /* used by task tracker executor */
-	bool upsertQuery;              /* only applies to modify tasks */
 	char replicationModel;         /* only applies to modify tasks */
 
+	/*
+	 * List of struct RelationRowLock. This contains an entry for each
+	 * query identified as a FOR [KEY] UPDATE/SHARE target. Citus
+	 * converts PostgreSQL's RowMarkClause to RelationRowLock in
+	 * RowLocksOnRelations().
+	 */
 	List *relationRowLockList;
+
 	bool modifyWithSubquery;
+
+	/*
+	 * List of struct RelationShard. This represents the mapping of relations
+	 * in the RTE list to shard IDs for a task for the purposes of:
+	 *  - Locking: See AcquireExecutorShardLocks()
+	 *  - Deparsing: See UpdateRelationToShardNames()
+	 *  - Relation Access Tracking
+	 */
 	List *relationShardList;
 
 	List *rowValuesLists;          /* rows to use when building multi-row INSERT */
@@ -229,21 +251,21 @@ typedef struct DistributedPlan
 	/* unique identifier of the plan within the session */
 	uint64 planId;
 
-	/* type of command to execute (SELECT/INSERT/...) */
-	CmdType operation;
+	/* specifies nature of modifications in query */
+	RowModifyLevel modLevel;
 
 	/* specifies whether a DML command has a RETURNING */
 	bool hasReturning;
 
+	/* a router executable query is executed entirely on a worker */
+	bool routerExecutable;
+
 	/* job tree containing the tasks to be executed on workers */
 	Job *workerJob;
 
 	/* local query that merges results from the workers */
 	Query *masterQuery;
 
-	/* a router executable query is executed entirely on a worker */
-	bool routerExecutable;
-
 	/* query identifier (copied from the top-level PlannedStmt) */
 	uint64 queryId;
 
@@ -256,7 +278,7 @@ typedef struct DistributedPlan
 	/* target list of an INSERT ... SELECT via the coordinator */
 	List *insertTargetList;
 
-	/* target relation of an INSERT ... SELECT via the coordinator */
+	/* target relation of a modification */
 	Oid targetRelationId;
 
 	/*
@@ -340,6 +362,7 @@ extern bool ShardIntervalsOverlap(ShardInterval *firstInterval,
 								  ShardInterval *secondInterval);
 extern bool CoPartitionedTables(Oid firstRelationId, Oid secondRelationId);
 extern ShardInterval ** GenerateSyntheticShardIntervalArray(int partitionCount);
+extern RowModifyLevel RowModifyLevelForQuery(Query *query);
 
 
 /* function declarations for Task and Task list operations */
@@ -351,6 +374,7 @@ extern List * TaskListDifference(const List *list1, const List *list2);
 extern List * AssignAnchorShardTaskList(List *taskList);
 extern List * FirstReplicaAssignTaskList(List *taskList);
 extern List * RoundRobinAssignTaskList(List *taskList);
+extern List * RoundRobinReorder(Task *task, List *placementList);
 extern int CompareTasksByTaskId(const void *leftElement, const void *rightElement);
 
 /* function declaration for creating Task */
