@@ -14,12 +14,15 @@
 #ifndef WORKER_PROTOCOL_H
 #define WORKER_PROTOCOL_H
 
+#include "postgres.h"
+
 #include "fmgr.h"
 #include "distributed/shardinterval_utils.h"
 #include "lib/stringinfo.h"
 #include "nodes/parsenodes.h"
 #include "storage/fd.h"
 #include "utils/array.h"
+#include "distributed/version_compat.h"
 
 
 /* Number of rows to prefetch when reading data with a cursor */
@@ -79,6 +82,7 @@ typedef struct HashPartitionContext
 	FmgrInfo *comparisonFunction;
 	ShardInterval **syntheticShardIntervalArray;
 	uint32 partitionCount;
+	Oid collation;
 	bool hasUniformHashDistribution;
 } HashPartitionContext;
 
@@ -91,7 +95,7 @@ typedef struct HashPartitionContext
  */
 typedef struct FileOutputStream
 {
-	File fileDescriptor;
+	FileCompat fileCompat;
 	StringInfo fileBuffer;
 	StringInfo filePath;
 } FileOutputStream;
